@@ -434,7 +434,7 @@ public class PlaybackService extends MediaBrowserServiceCompat{
             final int state = intent.getIntExtra("state", 0);
 
             // skip all headsets events if there is a call
-            final TelephonyManager telManager = (TelephonyManager) VLCApplication.getAppContext().getSystemService(Context.TELEPHONY_SERVICE);
+            final TelephonyManager telManager = (TelephonyManager) PlaybackService.this.getApplicationContext().getSystemService(Context.TELEPHONY_SERVICE);
             if (telManager != null && telManager.getCallState() != TelephonyManager.CALL_STATE_IDLE) return;
 
             /*
@@ -450,9 +450,8 @@ public class PlaybackService extends MediaBrowserServiceCompat{
              * Remote / headset control events
              */
             if (action.equalsIgnoreCase(Constants.ACTION_REMOTE_PLAYPAUSE)) {
-                if (!playlistManager.hasCurrentMedia())
-                    loadLastAudioPlaylist();
-                if (isPlaying()) pause();
+                if (!playlistManager.hasCurrentMedia()) loadLastAudioPlaylist();
+                else if (isPlaying()) pause();
                 else play();
             } else if (action.equalsIgnoreCase(Constants.ACTION_REMOTE_PLAY)) {
                 if (!isPlaying() && playlistManager.hasCurrentMedia())
